@@ -155,7 +155,7 @@ void AbstractAccount::registerApplication(const QString &appName, const QString
     const QUrl regUrl = apiUrl(QStringLiteral("/api/v1/apps"));
     const QJsonObject obj{
         {QStringLiteral("client_name"), appName},
-        {QStringLiteral("redirect_uris"), QJsonArray{m_redirectUri}},
+        {QStringLiteral("redirect_uris"), m_redirectUri},
         {QStringLiteral("scopes"), QStringLiteral("read write follow %1").arg(m_additionalScopes).trimmed()},
         {QStringLiteral("website"), website},
     };
@@ -721,6 +721,54 @@ QStringList AbstractAccount::attachmentFilterStrings() const
     return m_attachmentFilterStrings;
 }
 
+void AbstractAccount::unknownNotification()
+{
+}
+
+void AbstractAccount::annualReportNotification()
+{
+}
+
+void AbstractAccount::updateNotification()
+{
+}
+
+void AbstractAccount::statusNotification()
+{
+}
+
+void AbstractAccount::mentionNotification()
+{
+}
+
+void AbstractAccount::favoriteNotification()
+{
+}
+
+void AbstractAccount::boostNotification()
+{
+}
+
+void AbstractAccount::followNotification()
+{
+}
+
+void AbstractAccount::followRequestNotification()
+{
+}
+
+void AbstractAccount::pollNotification()
+{
+}
+
+void AbstractAccount::increaseFollowRequests()
+{
+}
+
+void AbstractAccount::decreaseFollowRequests()
+{
+}
+
 void AbstractAccount::followAccount(Identity *identity, bool reblogs, bool notify)
 {
     executeAction(identity,
