@@ -9,13 +9,14 @@
 #include "tokodon_http_debug.h"
 
 #ifdef HAVE_KUNIFIEDPUSH
-#include "ecdh.h"
 #include "tokodon_debug.h"
 #endif
 
 #include "messagefiltercontainer.h"
 #include "tokodon-version.h"
 
+#include <KLocalizedString>
+#include <QCoroSignal>
 #include <QFileInfo>
 #include <QHttpMultiPart>
 #include <QJsonDocument>
@@ -277,7 +278,8 @@ QWebSocket *Account::streamingSocket(const QString &stream)
     });
 
     QNetworkRequest request(url);
-    request.setHeader(QNetworkRequest::UserAgentHeader, QStringLiteral("Tokodon/").append(QStringLiteral(TOKODON_VERSION_STRING)));
+    request.setHeader(QNetworkRequest::UserAgentHeader,
+                      QStringLiteral("%1/%2").arg(QCoreApplication::applicationName(), QCoreApplication::applicationVersion()));
     socket->open(request);
 
     m_websockets[stream] = socket;
@@ -294,8 +296,8 @@ void Account::validateToken()
         this,
         [this, verify_credentials](QNetworkReply *reply) {
             if (!reply->isFinished()) {
-                qCWarning(TOKODON_HTTP) << "Authentification reply not finished" << username() << verify_credentials;
-                Q_EMIT authenticated(false, {});
+                qCWarning(TOKODON_HTTP) << "Authentication reply not finished" << username() << verify_credentials;
+                Q_EMIT authenticated(false, i18nc("@info:label Error message", "Network request was interrupted"));
                 return;
             }
 
@@ -304,14 +306,14 @@ void Account::validateToken()
 
             if (!doc.isObject()) {
                 qCWarning(TOKODON_HTTP) << "Authentication reply is not json" << username() << verify_credentials << data;
-                Q_EMIT authenticated(false, {});
+                Q_EMIT authenticated(false, i18nc("@info:label Error message", "Failed to parse credentials"));
                 return;
             }
 
             const auto object = doc.object();
             if (!object.contains("source"_L1)) {
                 qCWarning(TOKODON_HTTP) << "Authentication reply does not contains source" << username() << verify_credentials;
-                Q_EMIT authenticated(false, {});
+                Q_EMIT authenticated(false, i18nc("@info:label Error message", "Failed to parse credentials"));
                 return;
             }
 
@@ -410,7 +412,7 @@ void Account::writeToSettings()
     clientSecretJob->start();
 }
 
-void Account::buildFromSettings()
+QCoro::Task<> Account::buildFromSettings()
 {
     Q_ASSERT(config());
 
@@ -422,24 +424,27 @@ void Account::buildFromSettings()
     accessTokenJob->setInsecureFallback(true);
 #endif
     accessTokenJob->setKey(accessTokenKey());
-
-    connect(accessTokenJob, &QKeychain::ReadPasswordJob::finished, [this, accessTokenJob]() {
-        setAccessToken(accessTokenJob->textData());
-    });
+    accessTokenJob->setAutoDelete(false);
 
     accessTokenJob->start();
+    co_await qCoro(accessTokenJob, &QKeychain::ReadPasswordJob::finished);
 
     auto clientSecretJob = new QKeychain::ReadPasswordJob{QStringLiteral("Tokodon"), this};
 #ifdef SAILFISHOS
     clientSecretJob->setInsecureFallback(true);
 #endif
     clientSecretJob->setKey(clientSecretKey());
-
-    connect(clientSecretJob, &QKeychain::ReadPasswordJob::finished, [this, clientSecretJob]() {
-        m_client_secret = clientSecretJob->textData();
-    });
-
+    clientSecretJob->setAutoDelete(false);
     clientSecretJob->start();
+    co_await qCoro(clientSecretJob, &QKeychain::ReadPasswordJob::finished);
+
+    setAccessToken(accessTokenJob->textData());
+    m_client_secret = clientSecretJob->textData();
+
+    validateToken();
+
+    accessTokenJob->deleteLater();
+    clientSecretJob->deleteLater();
 }
 
 void Account::checkForFollowRequests()
@@ -507,22 +512,24 @@ void Account::subscribePushNotifications()
 #ifdef HAVE_KUNIFIEDPUSH
     Q_ASSERT(!m_hasPushSubscription);
 
-    // Generate 16 random bytes
-    QByteArray randArray;
-    for (int i = 0; i < 16; i++) {
-        randArray.push_back(QRandomGenerator::global()->generate());
-    }
+    auto connector = NetworkController::instance().connector();
+
+    Q_ASSERT(!m_instanceVapidPublicKey.isEmpty());
+    connector->setVapidPublicKey(m_instanceVapidPublicKey);
 
     QUrlQuery formdata = buildNotificationFormData();
     formdata.addQueryItem(QStringLiteral("subscription[endpoint]"), QUrl(NetworkController::instance().endpoint).toString());
 
-    // TODO: save this keypair in the keychain
-    const auto keys = generateECDHKeypair();
+    const auto publicKey = connector->contentEncryptionPublicKey();
+    const auto authSecret = connector->contentEncryptionAuthSecret();
 
-    formdata.addQueryItem(QStringLiteral("subscription[keys][p256dh]"), QString::fromUtf8(exportPublicKey(keys).toBase64(QByteArray::Base64UrlEncoding)));
-    formdata.addQueryItem(QStringLiteral("subscription[keys][auth]"), QString::fromUtf8(randArray.toBase64(QByteArray::Base64UrlEncoding)));
+    formdata.addQueryItem(QStringLiteral("subscription[keys][p256dh]"),
+                          QString::fromLatin1(publicKey.toBase64(QByteArray::Base64UrlEncoding | QByteArray::OmitTrailingEquals)));
+    formdata.addQueryItem(QStringLiteral("subscription[keys][auth]"),
+                          QString::fromLatin1(authSecret.toBase64(QByteArray::Base64UrlEncoding | QByteArray::OmitTrailingEquals)));
 
     formdata.addQueryItem(QStringLiteral("data[policy]"), QStringLiteral("all"));
+    formdata.addQueryItem(QStringLiteral("subscription[standard]"), QStringLiteral("true"));
 
     post(
         apiUrl(QStringLiteral("/api/v1/push/subscription")),
