@@ -5,8 +5,8 @@
 #pragma once
 
 #include "account/notificationhandler.h"
+#include "datatypes/post.h"
 #include "timeline/notification.h"
-#include "timeline/post.h"
 
 #include <KAboutData>
 
