@@ -16,6 +16,7 @@ class NotificationModel : public AbstractTimelineModel
     QML_ELEMENT
 
     Q_PROPERTY(QStringList excludeTypes READ excludeTypes WRITE setExcludesTypes NOTIFY excludeTypesChanged)
+    Q_PROPERTY(bool fullyRead READ fullyRead NOTIFY readMarkerChanged)
 
 public:
     enum NotificationRoles {
@@ -23,6 +24,7 @@ public:
         RelationshipSeveranceEventRole,
         ModerationWarningRole,
         AnnualReportEventRole,
+        UnreadRole,
     };
 
     explicit NotificationModel(QObject *parent = nullptr);
@@ -51,6 +53,8 @@ public:
 
     Q_INVOKABLE void markAllNotificationsAsRead();
 
+    bool fullyRead() const;
+
 public Q_SLOTS:
     /**
      * @brief Reply to the notification at @p index.
@@ -101,9 +105,12 @@ Q_SIGNALS:
      */
     void wantReply(AbstractAccount *account, Post *post, const QModelIndex &index);
 
+    void readMarkerChanged();
+
 protected:
     void fetchMore(const QModelIndex &parent) override;
     [[nodiscard]] bool canFetchMore(const QModelIndex &parent) const override;
+    void fetchLastReadId();
 
     QString m_timelineName;
     AccountManager *m_manager = nullptr;
@@ -111,4 +118,7 @@ protected:
     QList<std::shared_ptr<Notification>> m_notifications;
     QStringList m_excludeTypes;
     std::optional<QUrl> m_next;
+    bool m_fetchingLastReadId = false;
+    bool m_fetchedLastReadId = false;
+    QString m_lastReadId;
 };
